package main

import (
	"bytes"
	"github.com/pierrec/lz4"
	"io"
	"log"
	"math"
	"net"
	"os"
	"strconv"
	"time"
)

var (
	packets       = 0
	events        = 0
	LineSeparator = []byte("\n")
)

func main() {

	listen, err := net.Listen("tcp4", ":"+strconv.Itoa(1200))
	if err != nil {
		log.Fatalf("Socket listen port failed: %s", err)
		os.Exit(1)
	}
	defer listen.Close()

	for {
		conn, err := listen.Accept()
		if err != nil {
			log.Fatalln(err)
			continue
		}
		go handler(conn)
	}
}

func handler(conn net.Conn) {

	log.Printf("Connected client")

	defer conn.Close()

	var (
		start = time.Now()
		buf   = make([]byte, 10240)
	)

	log.Printf("Reading lz4")
	zr := lz4.NewReader(conn)

	for {
		n, err := zr.Read(buf)
		if err == io.EOF {
			log.Printf("Disconnected client")
			return
		} else if err != nil {
			log.Fatalf("Receive data failed: %s", err)
			return
		}
		processMessage(buf[:n], start)
	}
}

func processMessage(message []byte, start time.Time) {

	packets += 1
	for {
		next := bytes.Index(message, LineSeparator)
		if next == -1 {
			return
		}
		if next == 0 {
			message = message[1:]
			continue
		}
		events += 1
		if events%100000 == 0 {
			since := time.Since(start).Seconds()
			pps := math.Floor(float64(packets) / since)
			eps := math.Floor(float64(events) / since)
			log.Printf("Received %v (%v/s), events %v (%v/s)", packets, pps, events, eps)
		}
		message = message[next+1:]
	}
}
