package main

import (
	"github.com/pierrec/lz4"
	"io"
	"log"
	"math"
	"net"
	"strconv"
	"strings"
	"time"
)

var (
	total = 0
	start = time.Now()
)

func main() {

	addr := strings.Join([]string{"127.0.0.1", strconv.Itoa(1200)}, ":")
	tcpAddr, err := net.ResolveTCPAddr("tcp", addr)
	if err != nil {
		log.Fatalln(err)
	}
	conn, err := net.DialTCP("tcp", nil, tcpAddr)
	if err != nil {
		log.Fatalln(err)
	}
	defer conn.Close()
	zw := lz4.NewWriter(conn)
	zh := lz4.Header{
		BlockDependency: false,
		BlockChecksum:   false,
		BlockMaxSize:    2 << 15, // 64kb
		NoChecksum:      true,
		HighCompression: false,
	}
	zw.Header = zh
	writeMany(zw)
}

func writeMany(conn io.Writer) {

	start = time.Now()
	for {
		message := []byte("100-salchipapa\n")
		bytes, err := conn.Write(message)
		if err != nil {
			log.Fatalln(err)
		}
		if bytes == 0 {
			log.Printf("No bytes wrote")
		}
		total += 1
		if total%100000 == 0 {
			elapsed := time.Since(start).Seconds()
			mps := math.Floor(float64(total) / elapsed)
			log.Printf("Sent %v, %v/s", total, mps)
		}
	}
}
